@@ -1,4 +1,3 @@
-/* $Id$ */
 /* gtkmm - a C++ wrapper for the Gtk toolkit
  *
  * Copyright 1999-2002 The gtkmm Development Team
@@ -21,6 +20,65 @@
 #ifndef _GTKMM_H
 #define _GTKMM_H
 
+/** @mainpage gtkmm Reference Manual
+ *
+ * @section description Description
+ *
+ * gtkmm is the official C++ interface for the popular GUI library GTK+.
+ * Highlights include typesafe callbacks, and a comprehensive set of widgets
+ * that are easily extensible via inheritance.
+ *
+ * For instance, see @ref Widgets, @ref Dialogs, @ref TreeView "TreeView" and
+ * @ref TextView "TextView".
+ *
+ * See also the
+ * <a href="http://library.gnome.org/devel/gtkmm-tutorial/stable/">Programming
+ * with gtkmm</a> book.
+ *
+ *
+ * @section features Features
+ *
+ * - GTK+’s mature, capable set of @ref widgets Widgets. See
+ *   <a href="http://www.gtk.org/">the GTK+ website</a> for more information.
+ * - Use inheritance to derive custom widgets.
+ * - Type-safe signal handlers (slots), in standard C++, using
+ *   <a href="http://libsigc.sourceforge.net/">libsigc++</a>.
+ * - Polymorphism.
+ * - Use of the Standard C++ Library, including strings, containers and
+ *   iterators.
+ * - Full internationalisation with UTF8.
+ * - Complete C++ memory management.
+ *   - Member instances or dynamic new and delete.
+ *   - Optional automatic deletion of child widgets.
+ *   - No manual reference-counting.
+ * - Full use of C++ namespaces.
+ * - No macros.
+ *
+ * @section basics Basic Usage
+ *
+ * Include the gtkmm header:
+ * @code
+ * #include <gtkmm.h>
+ * @endcode
+ * (You may include individual headers, such as @c gtkmm/button.h instead.)
+ *
+ * If your source file is @c program.cc, you can compile it with:
+ * @code
+ * g++ program.cc -o program  `pkg-config --cflags --libs gtkmm-3.0`
+ * @endcode
+ *
+ * Alternatively, if using autoconf, use the following in @c configure.ac:
+ * @code
+ * PKG_CHECK_MODULES([GTKMM], [gtkmm-3.0])
+ * @endcode
+ * Then use the generated @c GTKMM_CFLAGS and @c GTKMM_LIBS variables in the
+ * project @c Makefile.am files. For example:
+ * @code
+ * program_CPPFLAGS = $(GTKMM_CFLAGS)
+ * program_LDADD = $(GTKMM_LIBS)
+ * @endcode
+ */
+
 /* Gtkmm version.  */
 extern const int gtkmm_major_version;
 extern const int gtkmm_minor_version;
@@ -60,13 +118,11 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/cellrenderertoggle.h>
 #include <gtkmm/colorbutton.h>
 #include <gtkmm/colorselection.h>
-#include <gtkmm/combo.h> //TODO: Deprecated.
 #include <gtkmm/combobox.h>
 #include <gtkmm/comboboxentry.h>
 #include <gtkmm/comboboxentrytext.h>
 #include <gtkmm/comboboxtext.h>
 #include <gtkmm/container.h>
-#include <gtkmm/curve.h>
 #include <gtkmm/dialog.h>
 #include <gtkmm/drawingarea.h>
 #include <gtkmm/editable.h>
@@ -79,7 +135,6 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/filechooserdialog.h>
 #include <gtkmm/filechooserwidget.h>
 #include <gtkmm/filefilter.h>
-#include <gtkmm/fileselection.h> //TODO: Deprecated.
 #include <gtkmm/fixed.h>
 #include <gtkmm/fontbutton.h>
 #include <gtkmm/fontselection.h>
@@ -94,7 +149,6 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/image.h>
 #include <gtkmm/imagemenuitem.h>
 #include <gtkmm/infobar.h>
-#include <gtkmm/inputdialog.h>
 #include <gtkmm/item.h>
 #include <gtkmm/calendar.h>
 #include <gtkmm/invisible.h>
@@ -114,7 +168,6 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/notebook.h>
 #include <gtkmm/object.h>
 #include <gtkmm/offscreenwindow.h>
-#include <gtkmm/optionmenu.h>
 #include <gtkmm/paned.h>
 #include <gtkmm/pagesetup.h>
 #ifndef G_OS_WIN32
@@ -181,7 +234,6 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/toggletoolbutton.h>
 #include <gtkmm/menutoolbutton.h>
 #include <gtkmm/tooltip.h>
-#include <gtkmm/tooltips.h>
 #include <gtkmm/treemodel.h>
 #include <gtkmm/treemodelfilter.h>
 #include <gtkmm/treemodelsort.h>
@@ -197,4 +249,3 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/window.h>
 
 #endif /* #ifndef GTKMM_H */
-
