@@ -22,6 +22,7 @@
 // We always need to generate the .defs for all types because the code
 // using deprecated API is generated unconditionally and only disabled
 // at compile time.
+#undef ATK_DISABLE_DEPRECATED
 #undef GDK_DISABLE_DEPRECATED
 #undef GTK_DISABLE_DEPRECATED
 
@@ -36,6 +37,26 @@ int main(int argc, char** argv)
 {
   gtk_init(&argc, &argv);
 
+  void *const g_class_atk_no_op_object = g_type_class_ref(ATK_TYPE_NO_OP_OBJECT);
+
+  std::cout << get_defs( ATK_TYPE_OBJECT )
+            << get_defs( ATK_TYPE_COMPONENT )
+            << get_defs( ATK_TYPE_ACTION )
+            << get_defs( ATK_TYPE_EDITABLE_TEXT )
+            << get_defs( ATK_TYPE_HYPERLINK )
+            << get_defs( ATK_TYPE_HYPERTEXT )
+            << get_defs( ATK_TYPE_IMAGE )
+            << get_defs( ATK_TYPE_SELECTION )
+            << get_defs( ATK_TYPE_TABLE )
+            << get_defs( ATK_TYPE_TEXT )
+            << get_defs( ATK_TYPE_VALUE )
+            << get_defs( ATK_TYPE_REGISTRY )
+            << get_defs( ATK_TYPE_RELATION )
+            << get_defs( ATK_TYPE_RELATION_SET )
+            << get_defs( ATK_TYPE_STATE_SET );
+
+  g_type_class_unref(g_class_atk_no_op_object);
+
   std::cout << get_defs( GDK_TYPE_COLORMAP )
             << get_defs( GDK_TYPE_DRAG_CONTEXT )
             << get_defs( GDK_TYPE_DISPLAY )
@@ -72,7 +93,6 @@ int main(int argc, char** argv)
             << get_defs( GTK_TYPE_CALENDAR )
             << get_defs( GTK_TYPE_CHECK_BUTTON )
             << get_defs( GTK_TYPE_CHECK_MENU_ITEM )
-            << get_defs( GTK_TYPE_CLIST ) /* Deprecated */
             << get_defs( GTK_TYPE_CELL_LAYOUT )
             << get_defs( GTK_TYPE_CELL_RENDERER )
             << get_defs( GTK_TYPE_CELL_RENDERER_ACCEL )
@@ -87,12 +107,9 @@ int main(int argc, char** argv)
             << get_defs( GTK_TYPE_CLIPBOARD )
             << get_defs( GTK_TYPE_COLOR_BUTTON )
             << get_defs( GTK_TYPE_COLOR_SELECTION )
-            << get_defs( GTK_TYPE_COMBO ) /* Deprecated */
             << get_defs( GTK_TYPE_COMBO_BOX )
             << get_defs( GTK_TYPE_CONTAINER )
-            << get_defs( GTK_TYPE_CTREE ) /* Deprecated */
             << get_defs( GTK_TYPE_CELL_VIEW )
-            << get_defs( GTK_TYPE_CURVE )
             << get_defs( GTK_TYPE_DIALOG )
             << get_defs( GTK_TYPE_DRAWING_AREA )
             << get_defs( GTK_TYPE_EDITABLE )
@@ -105,7 +122,6 @@ int main(int argc, char** argv)
             << get_defs( GTK_TYPE_FILE_CHOOSER_BUTTON )
             << get_defs( GTK_TYPE_FILE_CHOOSER_DIALOG )
             << get_defs( GTK_TYPE_FILE_CHOOSER_WIDGET )
-            << get_defs( GTK_TYPE_FILE_SELECTION ) /* Deprecated */
             << get_defs( GTK_TYPE_FIXED )
             << get_defs( GTK_TYPE_FONT_BUTTON )
             << get_defs( GTK_TYPE_FONT_SELECTION )
@@ -116,15 +132,12 @@ int main(int argc, char** argv)
             << get_defs( GTK_TYPE_IMAGE )
             << get_defs( GTK_TYPE_IMAGE_MENU_ITEM )
             << get_defs( GTK_TYPE_INFO_BAR )
-            << get_defs( GTK_TYPE_INPUT_DIALOG )
             << get_defs( GTK_TYPE_INVISIBLE )
             << get_defs( GTK_TYPE_ITEM )
             << get_defs( GTK_TYPE_ICON_VIEW )
             << get_defs( GTK_TYPE_LABEL )
             << get_defs( GTK_TYPE_LAYOUT )
             << get_defs( GTK_TYPE_LINK_BUTTON )
-            << get_defs( GTK_TYPE_LIST )
-            << get_defs( GTK_TYPE_LIST_ITEM )
             << get_defs( GTK_TYPE_MENU )
             << get_defs( GTK_TYPE_MENU_BAR )
             << get_defs( GTK_TYPE_MENU_ITEM )
@@ -135,15 +148,10 @@ int main(int argc, char** argv)
             << get_defs( GTK_TYPE_NOTEBOOK )
             << get_defs( GTK_TYPE_OBJECT )
             << get_defs( GTK_TYPE_OFFSCREEN_WINDOW )
-            << get_defs( GTK_TYPE_OPTION_MENU )
             << get_defs( GTK_TYPE_ORIENTABLE )
             << get_defs( GTK_TYPE_PANED )
-            << get_defs( GTK_TYPE_PIXMAP )
 #if !defined(G_OS_WIN32)
             << get_defs( GTK_TYPE_PLUG )
-#endif /* G_OS_WIN32 */
-            << get_defs( GTK_TYPE_PREVIEW )
-#if !defined(G_OS_WIN32)
             << get_defs( GTK_TYPE_PRINTER )
             << get_defs( GTK_TYPE_PRINT_JOB )
 #endif /* G_OS_WIN32 */
@@ -185,7 +193,6 @@ int main(int argc, char** argv)
             << get_defs( GTK_TYPE_STYLE )
             << get_defs( GTK_TYPE_TABLE )
             << get_defs( GTK_TYPE_TEAROFF_MENU_ITEM )
-            << get_defs( GTK_TYPE_TIPS_QUERY )
             << get_defs( GTK_TYPE_TOGGLE_BUTTON )
             << get_defs( GTK_TYPE_TOOLBAR )
             << get_defs( GTK_TYPE_TOOL_ITEM )
@@ -200,7 +207,6 @@ int main(int argc, char** argv)
             << get_defs( GTK_TYPE_TOGGLE_ACTION )
             << get_defs( GTK_TYPE_TOGGLE_TOOL_BUTTON )
             << get_defs( GTK_TYPE_TOOLTIP )
-            << get_defs( GTK_TYPE_TOOLTIPS )
             << get_defs( GTK_TYPE_TREE_SELECTION )
             << get_defs( GTK_TYPE_TREE_MODEL )
             << get_defs( GTK_TYPE_TREE_MODEL_FILTER )
